﻿using Microsoft.AspNetCore.DataProtection.KeyManagement;
using System;

namespace WF_WebAdmin.Converter
{
    /// <summary>
    /// Représente un objet Data Transfer Object (DTO) pour une citation.
    /// </summary>
    public class QuoteDTO
    {
        /// <summary>
        /// Identifiant de la citation.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// Contenu de la citation.
        /// </summary>
        public string Content { get; set; }

        /// <summary>
        /// Nombre de "likes" de la citation.
        /// </summary>
        public int Likes { get; set; }

        /// <summary>
        /// Langue de la citation.
        /// </summary>
        public string Langue { get; set; }

        /// <summary>
        /// Indique si la citation est valide.
        /// </summary>
        public bool IsValide { get; set; }

        /// <summary>
        /// Raison pour laquelle la citation pourrait être invalide.
        /// </summary>
        public string? Reason { get; set; }

        /// <summary>
        /// Identifiant du caractère associé à la citation (si applicable).
        /// </summary>
        public int? IdCaracter { get; set; }

        /// <summary>
        /// Nom du caractère associé à la citation (si applicable).
        /// </summary>
        public string NameCharac { get; set; }

        /// <summary>
        /// Identifiant de la source de la citation.
        /// </summary>
        public int? IdSource { get; set; }

        /// <summary>
        /// Titre de la source de la citation.
        /// </summary>
        public string TitleSrc { get; set; }

        /// <summary>
        /// Date de la source de la citation.
        /// </summary>
        public DateTime DateSrc { get; set; }

        /// <summary>
        /// Identifiant de l'utilisateur qui a vérifié la citation (si applicable).
        /// </summary>
        public int? IdUserVerif { get; set; }

        /// <summary>
        /// Nom de l'utilisateur qui a vérifié la citation.
        /// </summary>
        public string NameUser { get; set; }

        /// <summary>
        /// Identifiant de l'image associée à la citation (si applicable).
        /// </summary>
        public int? IdImg { get; set; }

        /// <summary>
        /// Chemin de l'image associée à la citation.
        /// </summary>
        public string ImgPath { get; set; }

        /// <summary>
        /// Initialise une nouvelle instance de <see cref="QuoteDTO"/>.
        /// </summary>
        /// <param name="id_quote">L'identifiant de la citation.</param>
        /// <param name="content">Le contenu de la citation.</param>
        /// <param name="likes">Le nombre de likes de la citation.</param>
        /// <param name="langue">La langue de la citation.</param>
        /// <param name="isValide">Indique si la citation est valide.</param>
        /// <param name="reason">La raison pour laquelle la citation peut être invalide.</param>
        /// <param name="id_caracter">L'identifiant du caractère associé à la citation.</param>
        /// <param name="name_charac">Le nom du caractère associé à la citation.</param>
        /// <param name="id_source">L'identifiant de la source de la citation.</param>
        /// <param name="title">Le titre de la source de la citation.</param>
        /// <param name="date">La date de la source de la citation.</param>
        /// <param name="id_user_verif">L'identifiant de l'utilisateur ayant vérifié la citation.</param>
        /// <param name="name_user">Le nom de l'utilisateur ayant vérifié la citation.</param>
        /// <param name="id_img">L'identifiant de l'image associée à la citation.</param>
        /// <param name="img_path">Le chemin de l'image associée à la citation.</param>
        public QuoteDTO(int id_quote, string content, int likes, string langue, bool isValide, string? reason, int? id_caracter, string name_charac, int? id_source, string title, DateTime date, int? id_user_verif, string name_user, int? id_img, string img_path)
        {
            this.Id = id_quote;
            this.Content = content;
            this.Likes = likes;
            this.Langue = langue;
            this.IsValide = isValide;
            this.Reason = reason;
            this.IdCaracter = id_caracter;
            this.NameCharac = name_charac;
            this.IdSource = id_source;
            this.TitleSrc = title;
            this.DateSrc = date;
            this.IdUserVerif = id_user_verif;
            this.NameUser = name_user;
            this.IdImg = id_img;
            this.ImgPath = img_path;
        }
    }
}
