﻿using WF_WebAdmin.Model;

namespace WF_WebAdmin.Converter
{
    /// <summary>
    /// Classe d'extension pour la conversion entre les objets <see cref="Quote"/> et <see cref="QuoteDTO"/>.
    /// </summary>
    public class QuoteExtension
    {
        /// <summary>
        /// Convertit un objet <see cref="Quote"/> en un objet <see cref="QuoteDTO"/>.
        /// </summary>
        /// <param name="q">L'objet <see cref="Quote"/> à convertir.</param>
        /// <returns>Un objet <see cref="QuoteDTO"/> contenant les données de l'objet <see cref="Quote"/>.</returns>
        public QuoteDTO QuoteToDTO(Quote q)
        {
            // Conversion des propriétés de Quote en QuoteDTO
            QuoteDTO quote = new QuoteDTO(
                q.Id, 
                q.Content, 
                q.Like, 
                q.Langue, 
                q.IsValid, 
                null, // Reason non défini ici
                null, // IdCaracter non défini ici
                q.Charac, 
                null, // IdSource non défini ici
                q.TitleSrc, 
                q.DateSrc, 
                null, // IdUserVerif non défini ici
                q.UserProposition, 
                null, // IdImg non défini ici
                q.ImgPath
            );
            return quote;
        }

        /// <summary>
        /// Convertit un objet <see cref="QuoteDTO"/> en un objet <see cref="Quote"/>.
        /// </summary>
        /// <param name="q">L'objet <see cref="QuoteDTO"/> à convertir.</param>
        /// <returns>Un objet <see cref="Quote"/> contenant les données de l'objet <see cref="QuoteDTO"/>.</returns>
        public Quote DTOToQuote(QuoteDTO q)
        {
            // Conversion des propriétés de QuoteDTO en Quote
            Quote quote = new Quote(
                q.Id, 
                q.Content, 
                q.NameCharac, 
                q.ImgPath, 
                q.TitleSrc, 
                q.DateSrc, 
                q.Likes, 
                q.Langue, 
                q.NameUser, 
                q.IsValide
            );
            return quote;
        }
    }
}
