﻿using WF_WebAdmin.Model;

namespace WF_WebAdmin.Converter
{
    /// <summary>
    /// Représente un objet Data Transfer Object (DTO) pour un utilisateur.
    /// Utilisé pour transmettre les informations d'un utilisateur entre différentes couches de l'application.
    /// </summary>
    public class UserDTO
    {
        /// <summary>
        /// Obtient ou définit l'image de l'utilisateur.
        /// </summary>
        public string Image { get; set; }

        /// <summary>
        /// Obtient ou définit le nom de l'utilisateur.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Obtient ou définit l'adresse email de l'utilisateur.
        /// </summary>
        public string Email { get; set; }

        /// <summary>
        /// Obtient ou définit la date de création de l'utilisateur.
        /// </summary>
        public DateTime DateCreation { get; set; }

        /// <summary>
        /// Obtient ou définit une valeur indiquant si l'utilisateur est un administrateur.
        /// </summary>
        public Boolean IsAdmin { get; set; }

        /// <summary>
        /// Obtient ou définit la liste des commentaires associés à l'utilisateur.
        /// </summary>
        public List<Commentary> Comments { get; set; }

        /// <summary>
        /// Initialise une nouvelle instance de la classe <see cref="UserDTO"/> avec les informations de base d'un utilisateur.
        /// </summary>
        /// <param name="image">L'image de l'utilisateur.</param>
        /// <param name="name">Le nom de l'utilisateur.</param>
        /// <param name="email">L'email de l'utilisateur.</param>
        /// <param name="dateCreation">La date de création du compte utilisateur.</param>
        public UserDTO(string image, string name, string email, DateTime dateCreation)
        {
            this.Image = image;
            this.Name = name;
            this.Email = email;
            this.DateCreation = dateCreation;
        }
    }
}
