namespace WF_WebAdmin.Model
{
    /// <summary>
    /// Représente un quiz avec une question et plusieurs réponses possibles.
    /// </summary>
    public class Quiz
    {
        /// <summary>
        /// Identifiant unique du quiz.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// La question posée dans le quiz.
        /// </summary>
        public string Question { get; set; }

        /// <summary>
        /// Réponse A possible pour le quiz.
        /// </summary>
        public string AnswerA { get; set; }

        /// <summary>
        /// Réponse B possible pour le quiz.
        /// </summary>
        public string AnswerB { get; set; }

        /// <summary>
        /// Réponse C possible pour le quiz.
        /// </summary>
        public string AnswerC { get; set; }

        /// <summary>
        /// Réponse D possible pour le quiz.
        /// </summary>
        public string AnswerD { get; set; }

        /// <summary>
        /// Réponse correcte au quiz (A, B, C ou D).
        /// </summary>
        public string CAnswer { get; set; }

        /// <summary>
        /// Indique si le quiz est valide.
        /// </summary>
        public bool IsValid { get; set; }

        /// <summary>
        /// Proposition de l'utilisateur pour valider le quiz.
        /// </summary>
        public string UserProposition { get; set; }

        /// <summary>
        /// Initialise une nouvelle instance de la classe <see cref="Quiz"/>.
        /// </summary>
        /// <param name="id">L'identifiant du quiz.</param>
        /// <param name="question">La question posée dans le quiz.</param>
        /// <param name="answerA">Réponse A possible.</param>
        /// <param name="answerB">Réponse B possible.</param>
        /// <param name="answerC">Réponse C possible.</param>
        /// <param name="answerD">Réponse D possible.</param>
        /// <param name="cAnswer">Réponse correcte (A, B, C ou D).</param>
        /// <param name="isValid">Indique si le quiz est valide.</param>
        /// <param name="userProposition">Proposition de l'utilisateur.</param>
        public Quiz(int id, string question, string answerA, string answerB, string answerC, string answerD, string cAnswer, bool isValid, string userProposition)
        {
            Id = id;
            Question = question;
            AnswerA = answerA;
            AnswerB = answerB;
            AnswerC = answerC;
            AnswerD = answerD;
            CAnswer = cAnswer;
            IsValid = isValid;
            UserProposition = userProposition;
        }

        /// <summary>
        /// Initialise une nouvelle instance de la classe <see cref="Quiz"/> avec une valeur par défaut pour la validité et la proposition de l'utilisateur.
        /// </summary>
        /// <param name="id">L'identifiant du quiz.</param>
        /// <param name="question">La question posée dans le quiz.</param>
        /// <param name="answerA">Réponse A possible.</param>
        /// <param name="answerB">Réponse B possible.</param>
        /// <param name="answerC">Réponse C possible.</param>
        /// <param name="answerD">Réponse D possible.</param>
        /// <param name="cAnswer">Réponse correcte (A, B, C ou D).</param>
        public Quiz(int id, string question, string answerA, string answerB, string answerC, string answerD, string cAnswer)
        {
            Id = id;
            Question = question;
            AnswerA = answerA;
            AnswerB = answerB;
            AnswerC = answerC;
            AnswerD = answerD;
            CAnswer = cAnswer;
            IsValid = true;
            UserProposition = "Admin";
        }

        /// <summary>
        /// Constructeur par défaut pour la classe <see cref="Quiz"/>.
        /// </summary>
        public Quiz() {}
    }
}
