﻿namespace WF_WebAdmin.Model
{
    /// <summary>
    /// Représente une citation dans le système.
    /// </summary>
    public class Quote
    {
        /// <summary>
        /// Identifiant unique de la citation.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// Contenu de la citation.
        /// </summary>
        public string Content { get; set; }

        /// <summary>
        /// Nombre de "likes" reçus pour cette citation.
        /// </summary>
        public int Like { get; set; }

        /// <summary>
        /// Langue dans laquelle la citation est écrite.
        /// </summary>
        public string Langue { get; set; }

        /// <summary>
        /// Caractère associé à la citation (ex : personnage, auteur, etc.).
        /// </summary>
        public string Charac { get; set; }

        /// <summary>
        /// Chemin d'accès à l'image associée à la citation.
        /// </summary>
        public string ImgPath { get; set; }

        /// <summary>
        /// Titre de la source de la citation (ex : livre, film, etc.).
        /// </summary>
        public string TitleSrc { get; set; }

        /// <summary>
        /// Date de la source de la citation.
        /// </summary>
        public DateTime DateSrc { get; set; }

        /// <summary>
        /// Nom de l'utilisateur ayant proposé la citation.
        /// </summary>
        public string UserProposition { get; set; }

        /// <summary>
        /// Indique si la citation est valide.
        /// </summary>
        public bool IsValid { get; set; }

        /// <summary>
        /// Constructeur pour créer une nouvelle citation avec tous ses attributs.
        /// </summary>
        /// <param name="id">Identifiant de la citation.</param>
        /// <param name="content">Contenu de la citation.</param>
        /// <param name="charac">Caractère associé à la citation.</param>
        /// <param name="imgPath">Chemin de l'image associée.</param>
        /// <param name="titleSrc">Titre de la source.</param>
        /// <param name="dateSrc">Date de la source.</param>
        /// <param name="like">Nombre de "likes" reçus.</param>
        /// <param name="langue">Langue de la citation.</param>
        /// <param name="userProposition">Nom de l'utilisateur ayant proposé la citation.</param>
        /// <param name="isvalid">Indicateur de validité de la citation.</param>
        public Quote(int id, string content, string charac, string imgPath, string titleSrc, DateTime dateSrc, int like, string langue, string userProposition, bool isvalid)
        {
            Id = id;
            Content = content;
            Charac = charac;
            ImgPath = imgPath;
            TitleSrc = titleSrc;
            DateSrc = dateSrc;
            Like = like;
            Langue = langue;
            UserProposition = userProposition;
            IsValid = isvalid;
        }
    }
}







        /*
        public int Id { get; set; }
        public string Content { get; set; }
        public int Likes { get; set; }
        public string Langue { get; set; }
        public bool IsValide { get; set; }
        public string? Reason { get; set; }
        public int IdCaracter { get; set; }
        public int IdSource { get; set; }
        public int? IdUserVerif { get; set; }

        public Quote(int id, string content, int likes, string langue, bool isValide, string? reason, int idCaracter, int idSource, int idUserVerif)
        {
            Id = id;
            Content = content;
            Likes = likes;
            Langue = langue;
            IsValide = isValide;
            Reason = reason;
            IdCaracter = idCaracter;
            IdSource = idSource;
            IdUserVerif = idUserVerif;
        }

        public Quote(int id, string content, int likes, string langue, bool isValide, string? reason, int idCaracter, int idSource, int? idUserVerif)
        {
            Id = id;
            Content = content;
            Likes = likes;
            Langue = langue;
            IsValide = isValide;
            Reason = reason;
            IdCaracter = idCaracter;
            IdSource = idSource;
            IdUserVerif = idUserVerif;
        }
        */
    

