﻿namespace WF_WebAdmin.Model
{
    /// <summary>
    /// Modèle représentant une citation dans le système.
    /// Ce modèle est utilisé pour la validation des données avant leur persistance.
    /// </summary>
    public class QuoteModel
    {
        /// <summary>
        /// Identifiant unique de la citation.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// Contenu de la citation.
        /// La citation ne peut pas dépasser 300 caractères.
        /// </summary>
        [Required]
        [StringLength(300, ErrorMessage = "La citation ne peut pas dépasser les 300 caractères.")]
        public string Content { get; set; }

        /// <summary>
        /// Nombre de "likes" que la citation a reçus.
        /// </summary>
        public int Like { get; set; }

        /// <summary>
        /// Langue dans laquelle la citation est écrite.
        /// La langue est limitée à 2 caractères.
        /// </summary>
        [Required]
        [StringLength(2, ErrorMessage = "La langue ne peut pas dépasser 2 caractères.")]
        public string Langue { get; set; }

        /// <summary>
        /// Caractère associé à la citation (ex : auteur ou personnage).
        /// </summary>
        public string Charac { get; set; }

        /// <summary>
        /// Chemin d'accès à l'image associée à la citation.
        /// </summary>
        public string ImgPath { get; set; }

        /// <summary>
        /// Titre de la source de la citation (ex : livre, film, etc.).
        /// </summary>
        public string TitleSrc { get; set; }

        /// <summary>
        /// Date de la source de la citation.
        /// </summary>
        public DateTime DateSrc { get; set; }

        /// <summary>
        /// Nom de l'utilisateur ayant proposé la citation.
        /// </summary>
        public string UserProposition { get; set; }

        /// <summary>
        /// Indique si la citation est validée par le système.
        /// </summary>
        public bool IsValid { get; set; }
    }
}
