﻿namespace WF_WebAdmin.Model
{
    /// <summary>
    /// Représente un utilisateur dans le système.
    /// Cette classe contient des informations sur l'utilisateur, telles que son image, son nom, son email, la date de création de son compte,
    /// son statut d'administrateur et les commentaires qu'il a publiés.
    /// </summary>
    public class User
    {
        /// <summary>
        /// Identifiant unique de l'utilisateur.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// URL de l'image de profil de l'utilisateur.
        /// </summary>
        public string Image { get; set; }

        /// <summary>
        /// Nom de l'utilisateur.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Adresse email de l'utilisateur.
        /// </summary>
        public string Email { get; set; }

        /// <summary>
        /// Date de création du compte utilisateur.
        /// </summary>
        public DateTime DateCreation { get; set; }

        /// <summary>
        /// Indique si l'utilisateur a des privilèges d'administrateur.
        /// </summary>
        public bool IsAdmin { get; set; }

        /// <summary>
        /// Liste des commentaires publiés par l'utilisateur.
        /// </summary>
        public List<Commentary> Comments { get; set; }

        /// <summary>
        /// Constructeur pour créer un nouvel utilisateur avec des informations spécifiques.
        /// </summary>
        /// <param name="image">URL de l'image de profil de l'utilisateur.</param>
        /// <param name="name">Nom de l'utilisateur.</param>
        /// <param name="email">Adresse email de l'utilisateur.</param>
        /// <param name="dateCreation">Date de création du compte de l'utilisateur.</param>
        /// <param name="isAdmin">Indicateur si l'utilisateur est un administrateur.</param>
        public User(string image, string name, string email, DateTime dateCreation, bool isAdmin)
        {
            this.Image = image;
            this.Name = name;
            this.Email = email;
            this.DateCreation = dateCreation;
            IsAdmin = isAdmin;
        }

        /// <summary>
        /// Constructeur par défaut pour créer un utilisateur sans initialiser ses propriétés.
        /// </summary>
        public User() { }
    }
}
