﻿namespace WF_WebAdmin.Model
{
    /// <summary>
    /// Représente un utilisateur dans le système de connexion.
    /// Cette classe contient des informations nécessaires pour l'authentification et la gestion du profil utilisateur.
    /// </summary>
    public class UserLogin
    {
        /// <summary>
        /// Identifiant unique de l'utilisateur.
        /// </summary>
        public int Id { get; set; }

        /// <summary>
        /// URL de l'image de profil de l'utilisateur.
        /// </summary>
        public string Image { get; set; }

        /// <summary>
        /// Nom de l'utilisateur.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Indique si l'utilisateur possède des privilèges d'administrateur.
        /// </summary>
        public bool IsAdmin { get; set; }

        /// <summary>
        /// Mot de passe de l'utilisateur.
        /// </summary>
        public string Mdp { get; set; }

        /// <summary>
        /// Constructeur pour créer un objet <see cref="UserLogin"/> avec des informations d'authentification et de profil.
        /// </summary>
        /// <param name="id">Identifiant de l'utilisateur.</param>
        /// <param name="image">URL de l'image de profil de l'utilisateur.</param>
        /// <param name="name">Nom de l'utilisateur.</param>
        /// <param name="isAdmin">Indicateur si l'utilisateur est un administrateur.</param>
        /// <param name="mdp">Mot de passe de l'utilisateur.</param>
        public UserLogin(int id, string image, string name, bool isAdmin, string mdp)
        {
            Id = id;
            this.Image = image;
            this.Name = name;
            this.IsAdmin = isAdmin;
            this.Mdp = mdp;
        }

        /// <summary>
        /// Constructeur par défaut pour créer un objet <see cref="UserLogin"/> sans initialiser les propriétés.
        /// </summary>
        public UserLogin() { }
    }
}
