﻿using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Localization;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Pages
{
    /// <summary>
    /// Page d'accueil qui affiche des citations quotidiennes.
    /// </summary>
    public partial class Accueil
    {
        /// <summary>
        /// Tableau contenant les citations quotidiennes.
        /// </summary>
        private Quote[] Dailyquote;

        /// <summary>
        /// Service HttpClient pour faire des requêtes HTTP.
        /// </summary>
        [Inject]
        public HttpClient Http { get; set; }

        /// <summary>
        /// Service NavigationManager pour la gestion de la navigation dans l'application.
        /// </summary>
        [Inject]
        public NavigationManager NavigationManager { get; set; }

        /// <summary>
        /// Service pour la localisation des ressources (traductions) sur la page.
        /// </summary>
        [Inject]
        public IStringLocalizer<Accueil> Localizer { get; set; }

        /// <summary>
        /// Méthode appelée lors de l'initialisation du composant. 
        /// Elle charge les citations quotidiennes depuis un fichier JSON.
        /// </summary>
        /// <returns>Une tâche représentant l'opération asynchrone.</returns>
        protected override async Task OnInitializedAsync()
        {
            // Chargement des citations quotidiennes depuis le fichier JSON
            Dailyquote = await Http.GetFromJsonAsync<Quote[]>($"{NavigationManager.BaseUri}fake-dataDailyQuote.json");
        }
    }
}
