﻿using Microsoft.AspNetCore.Components;
using WF_WebAdmin.Service;
using WF_WebAdmin.Model;
using Microsoft.AspNetCore.Mvc;
using System.Text.RegularExpressions;
using System;

namespace WF_WebAdmin.Pages
{
    public partial class AddQuiz
    {
        [Inject]
        private IQuizService quizService { get; set; }

        [Inject]
        public NavigationManager NavigationManager { get; set; }

        private QuizModel QuizModel = new();

        /// <summary>
        /// Handles the form submission to create a new quiz.
        /// </summary>
        private async void HandleValidSubmit()
        {
            int id;
            id = await quizService.getNbQuiz(); // Fetch the current quiz count
            id++; // Increment the quiz ID to create a new quiz ID

            // Create and add the quiz using the validated inputs
            await quizService.addQuiz(new Quiz(
                id,
                validateInformation(QuizModel.Question),
                validateInformation(QuizModel.AnswerA),
                validateInformation(QuizModel.AnswerB),
                validateInformation(QuizModel.AnswerC),
                validateInformation(QuizModel.AnswerD),
                validateReponse(QuizModel.CAnswer)
            ));

            // Navigate to the quiz management page after adding the quiz
            NavigationManager.NavigateTo("modifquiz");
        }

        /// <summary>
        /// Handles the change in the correct answer selection.
        /// </summary>
        private void OnCAwnserChange(string item, object checkedValue)
        {
            QuizModel.CAnswer = item;
        }

        /// <summary>
        /// Validates each input (question or answers) to ensure it isn't null or empty.
        /// </summary>
        private static string validateInformation(string item)
        {
            if (string.IsNullOrWhiteSpace(item))
            {
                throw new ArgumentException("Input cannot be empty or whitespace.");
            }
            return item; // Return the valid input
        }

        /// <summary>
        /// Validates the selected correct answer to be one of the valid options (A, B, C, D).
        /// </summary>
        private static string validateReponse(string item) 
        {
            try
            {
                if (string.IsNullOrEmpty(item))
                {
                    throw new ArgumentNullException("Correct answer must be selected.");
                }

                // Ensure the answer is one of A, B, C, or D
                if (!Regex.IsMatch(item, "^[A-D]$"))
                {
                    throw new InvalidDataException($"Invalid answer choice: '{item}'. Answer must be one of A, B, C, or D.");
                }

                return item; // Return the valid answer
            }
            catch (Exception ex)
            {
                // Log error or show a message to the user
                Console.WriteLine(ex.Message);
                return "A"; // Return default answer "A" if validation fails
            }
        }
    }
}
