﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using System.Diagnostics;

namespace WF_WebAdmin.Pages
{
    /// <summary>
    /// Modèle de page Razor pour afficher les erreurs dans l'application.
    /// </summary>
    [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
    [IgnoreAntiforgeryToken]
    public class ErrorModel : PageModel
    {
        /// <summary>
        /// Identifiant unique de la requête pour le suivi des erreurs.
        /// </summary>
        public string? RequestId { get; set; }

        /// <summary>
        /// Indicateur pour afficher l'ID de la requête si ce dernier est disponible.
        /// </summary>
        public bool ShowRequestId => !string.IsNullOrEmpty(RequestId);

        private readonly ILogger<ErrorModel> _logger;

        /// <summary>
        /// Constructeur pour initialiser le modèle de page avec le service de journalisation.
        /// </summary>
        /// <param name="logger">Service de journalisation pour capturer les erreurs.</param>
        public ErrorModel(ILogger<ErrorModel> logger)
        {
            _logger = logger;
        }

        /// <summary>
        /// Méthode appelée lors de l'accès à la page d'erreur.
        /// Elle enregistre l'ID de la requête pour la journalisation et l'affichage des erreurs.
        /// </summary>
        public void OnGet()
        {
            // Capture de l'ID de la requête à partir de l'activité en cours ou du trace identifier
            RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier;
        }
    }
}
