﻿using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Localization;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Pages
{
    /// <summary>
    /// Composant Blazor pour la gestion de la connexion des utilisateurs.
    /// </summary>
    public partial class Login
    {
        /// <summary>
        /// Service de localisation pour gérer les textes multilingues dans la page de connexion.
        /// </summary>
        [Inject]
        public IStringLocalizer<Login> Localizer { get; set; }

        /// <summary>
        /// Objet représentant les informations de connexion de l'utilisateur.
        /// </summary>
        private UserLogin userLogin = new UserLogin();

        /// <summary>
        /// Objet représentant l'utilisateur connecté.
        /// </summary>
        [Inject]
        public UserLogin uLogin { get; set; }

        /// <summary>
        /// Message d'erreur affiché en cas de connexion échouée.
        /// </summary>
        private string ErrorConnexion;

        /// <summary>
        /// Liste des utilisateurs enregistrés pour la connexion.
        /// </summary>
        private List<UserLogin> usersConnexion;

        /// <summary>
        /// Service HTTP pour effectuer des requêtes.
        /// </summary>
        [Inject]
        public HttpClient Http { get; set; }

        /// <summary>
        /// Service de gestion de la navigation dans l'application Blazor.
        /// </summary>
        [Inject]
        public NavigationManager NavigationManager { get; set; }

        /// <summary>
        /// Méthode appelée lors de l'initialisation du composant pour charger les données des utilisateurs.
        /// </summary>
        /// <returns>Une tâche asynchrone représentant l'initialisation du composant.</returns>
        protected override async Task OnInitializedAsync()
        {
            // Chargement des utilisateurs depuis un fichier JSON simulé.
            usersConnexion = await Http.GetFromJsonAsync<List<UserLogin>>($"{NavigationManager.BaseUri}fake-dataUserLogin.json");
        }

        /// <summary>
        /// Méthode pour valider les informations de connexion de l'utilisateur.
        /// </summary>
        public void validlogin()
        {
            // Vérification si les informations de connexion sont renseignées
            if (!string.IsNullOrEmpty(userLogin.Name) || !string.IsNullOrEmpty(userLogin.Mdp))
            {
                foreach (var user in usersConnexion)
                {
                    // Vérification si les identifiants correspondent
                    if (userLogin.Name == user.Name && userLogin.Mdp == user.Mdp)
                    {
                        // Vérification si l'utilisateur est un administrateur
                        if (user.IsAdmin)
                        {
                            // Assignation de l'utilisateur à la session
                            uLogin.Id = userLogin.Id;
                            uLogin.Name = user.Name;
                            uLogin.Image = user.Image;

                            // Redirection vers la page d'accueil
                            NavigationManager.NavigateTo(NavigationManager.BaseUri + "accueil");
                            return;
                        }
                        else
                        {
                            // Message d'erreur pour utilisateur non admin
                            ErrorConnexion = "Connexion échouée, le nom ou le mot de passe sont incorrectes";
                        }
                    }
                    else
                    {
                        // Message d'erreur pour informations invalides
                        ErrorConnexion = "Connexion échouée, le nom ou le mot de passe sont incorrectes";
                    }
                }
            }
        }
    }
}
