using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using WF_WebAdmin.Model;
using WF_WebAdmin.Service;

namespace WF_WebAdmin.Pages
{
    /// <summary>
    /// Composant Blazor pour la gestion des citations, permettant la modification et la suppression de celles-ci.
    /// </summary>
    public partial class ModifQuote
    {
        /// <summary>
        /// Liste des citations à afficher dans le tableau.
        /// </summary>
        private Quote[] quotes;

        /// <summary>
        /// Valeur maximale d'éléments par page.
        /// </summary>
        private int MaxValue = 5;

        /// <summary>
        /// Nombre total d'éléments dans la liste des citations.
        /// </summary>
        private int totalItem;
        
        /// <summary>
        /// Citation actuellement sélectionnée pour modification.
        /// </summary>
        private Quote? selectedQuote;

        /// <summary>
        /// Indicateur de l'affichage de la popup de suppression.
        /// </summary>
        private bool showPopupDelete = false;

        /// <summary>
        /// Numéro de la page actuellement affichée.
        /// </summary>
        private int page = 1;

        /// <summary>
        /// Service pour gérer les citations injecté.
        /// </summary>
        [Inject]
        public IQuoteService QuoteService { get; set; }

        /// <summary>
        /// Méthode appelée pour récupérer les données de la page actuelle dans le tableau.
        /// </summary>
        /// <param name="e">Arguments de lecture de données pour le DataGrid.</param>
        private async Task OnReadData(DataGridReadDataEventArgs<Quote> e)
        {
            if (e.CancellationToken.IsCancellationRequested)
            {
                return;
            }

            var response = await QuoteService.getSomeQuote(e.PageSize, e.Page);

            if (!e.CancellationToken.IsCancellationRequested)
            {
                totalItem = await QuoteService.getNbQuote();
                quotes = response.ToArray();
                page = e.Page;
            }
        }

        /// <summary>
        /// Méthode pour fermer la popup (modification ou suppression).
        /// </summary>
        private void ClosePopup()
        {
            showPopupDelete = false;
            selectedQuote = null;
        }

        /// <summary>
        /// Méthode appelée pour afficher la popup de suppression d'une citation.
        /// </summary>
        /// <param name="q">Citation à supprimer.</param>
        private void OnDelete(Quote q)
        {
            selectedQuote = q;
            showPopupDelete = true;
        }

        /// <summary>
        /// Méthode pour supprimer une citation sélectionnée.
        /// </summary>
        private async void RemoveQuote()
        {
            if (selectedQuote != null)
            {
                await QuoteService.removeQuote(selectedQuote);
                selectedQuote= null;
                var response = await QuoteService.getSomeQuote(MaxValue, page);
                quotes = response.ToArray();
            }
            showPopupDelete= false;
        }
    }
}
