using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using WF_WebAdmin.Model;
using WF_WebAdmin.Service;

namespace WF_WebAdmin.Pages
{
    /// <summary>
    /// Composant Blazor pour gérer la validation des quiz.
    /// </summary>
    public partial class ValidQuiz
    {
        /// <summary>
        /// Liste des quiz à valider.
        /// </summary>
        private List<Quiz> quizzes;
        
        /// <summary>
        /// Client HTTP injecté pour effectuer des requêtes API.
        /// </summary>
        [Inject]
        public HttpClient Http { get; set; }

        /// <summary>
        /// Gestionnaire de navigation injecté pour gérer les URL.
        /// </summary>
        [Inject]
        public NavigationManager NavigationManager { get; set; }

        /// <summary>
        /// Service pour gérer les quiz injecté.
        /// </summary>
        [Inject]
        public IQuizService QuizService { get; set; }

        /// <summary>
        /// Méthode appelée lors de l'initialisation du composant. Charge la liste des quiz à valider.
        /// </summary>
        protected override async Task OnInitializedAsync()
        {
            quizzes = await QuizService.getQuizzesToValidate();
        }

        /// <summary>
        /// Méthode appelée lorsqu'on clique sur le bouton de validation d'un quiz.
        /// </summary>
        /// <param name="quiz">Le quiz à valider.</param>
        private void OnValidButton(Quiz quiz)
        {
            ValidateQuiz(quiz);
        }
        
        /// <summary>
        /// Valide un quiz en mettant à jour son état.
        /// </summary>
        /// <param name="quiz">Le quiz à valider.</param>
        private void ValidateQuiz(Quiz quiz)
        {
            Console.WriteLine($"Quiz {quiz.Id} validated!");

            Quiz newQuiz = quiz;
            newQuiz.IsValid = true;

            // Mis à jour de l'état du quiz
            QuizService.updateQuiz(quiz);
        }

        /// <summary>
        /// Méthode appelée lorsqu'on clique sur le bouton de rejet d'un quiz.
        /// </summary>
        /// <param name="quiz">Le quiz à rejeter.</param>
        private void OnRejectButton(Quiz quiz)
        {
            RejectQuiz(quiz);
        }

        /// <summary>
        /// Rejette un quiz en supprimant son état de validation.
        /// </summary>
        /// <param name="quiz">Le quiz à rejeter.</param>
        private void RejectQuiz(Quiz quiz)
        {
            Console.WriteLine($"Quiz {quiz.Id} rejected!");

            QuizService.removeQuiz(quiz.Id);
        }
    }
}
