using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service
{
    /// <summary>
    /// Interface définissant les opérations de gestion des quiz.
    /// </summary>
    public interface IQuizService
    {
        /// <summary>
        /// Ajoute un quiz.
        /// </summary>
        /// <param name="quiz">Quiz à ajouter.</param>
        public Task addQuiz(Quiz quiz);
        
        /// <summary>
        /// Met à jour un quiz existant.
        /// </summary>
        /// <param name="quiz">Quiz à mettre à jour.</param>
        public Task updateQuiz(Quiz quiz);
        
        /// <summary>
        /// Supprime un quiz par son identifiant.
        /// </summary>
        /// <param name="id">Identifiant du quiz à supprimer.</param>
        public Task removeQuiz(int id);
        
        /// <summary>
        /// Valide un quiz par son identifiant.
        /// </summary>
        /// <param name="id">Identifiant du quiz à valider.</param>
        public Task validateQuiz(int id);

        /// <summary>
        /// Récupère la liste de tous les quiz.
        /// </summary>
        /// <returns>Liste de tous les quiz.</returns>
        public Task<List<Quiz>> getQuizzes();

        /// <summary>
        /// Récupère la liste des quiz en attente de validation.
        /// </summary>
        /// <returns>Liste des quiz non validés.</returns>
        public Task<List<Quiz>> getQuizzesToValidate();

        /// <summary>
        /// Récupère un quiz spécifique par son identifiant.
        /// </summary>
        /// <param name="id">Identifiant du quiz.</param>
        /// <returns>Le quiz correspondant ou null s'il n'existe pas.</returns>
        public Task<Quiz> getQuiz(int id);

        /// <summary>
        /// Récupère une liste paginée de quiz.
        /// </summary>
        /// <param name="nb">Nombre de quiz par page.</param>
        /// <param name="page">Numéro de la page.</param>
        /// <returns>Liste des quiz correspondant à la pagination.</returns>
        public Task<List<Quiz>> getSommeQuiz(int nb, int page);

        /// <summary>
        /// Récupère le nombre total de quiz enregistrés.
        /// </summary>
        /// <returns>Nombre total de quiz.</returns>
        public Task<int> getNbQuiz();
    }
}
