﻿using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service
{
    /// <summary>
    /// Interface définissant les opérations de gestion des citations.
    /// </summary>
    public interface IQuoteService
    {
        /// <summary>
        /// Ajoute une citation.
        /// </summary>
        /// <param name="quote">Citation à ajouter.</param>
        public Task addQuote(Quote quote);

        /// <summary>
        /// Supprime une citation.
        /// </summary>
        /// <param name="quote">Citation à supprimer.</param>
        public Task removeQuote(Quote quote);

        /// <summary>
        /// Valide une citation.
        /// </summary>
        /// <param name="quote">Citation à valider.</param>
        public Task validQuote(Quote quote);

        /// <summary>
        /// Met à jour une citation existante.
        /// </summary>
        /// <param name="quote">Citation à mettre à jour.</param>
        public Task updateQuote(Quote quote);

        /// <summary>
        /// Récupère toutes les citations.
        /// </summary>
        /// <returns>Liste de toutes les citations.</returns>
        public Task<List<Quote>> getAllQuote();

        /// <summary>
        /// Récupère une liste paginée de citations.
        /// </summary>
        /// <param name="nb">Nombre de citations par page.</param>
        /// <param name="page">Numéro de la page.</param>
        /// <returns>Liste des citations correspondant à la pagination.</returns>
        public Task<List<Quote>> getSomeQuote(int nb, int page);

        /// <summary>
        /// Récupère une citation spécifique par son identifiant.
        /// </summary>
        /// <param name="id">Identifiant de la citation.</param>
        /// <returns>La citation correspondante ou null si elle n'existe pas.</returns>
        public Task<Quote> getOnequote(int id);

        /// <summary>
        /// Recherche des citations en fonction d'un critère.
        /// </summary>
        /// <param name="reserch">Terme de recherche.</param>
        /// <param name="argument">Liste des arguments pour affiner la recherche.</param>
        /// <returns>Liste des citations correspondant aux critères.</returns>
        public Task<List<Quote>> reserchQuote(string reserch, List<string> argument);

        /// <summary>
        /// Récupère toutes les citations non validées.
        /// </summary>
        /// <returns>Liste des citations non validées.</returns>
        public Task<List<Quote>> getAllQuoteInvalid();

        /// <summary>
        /// Récupère une liste paginée de citations non validées.
        /// </summary>
        /// <param name="nb">Nombre de citations par page.</param>
        /// <param name="page">Numéro de la page.</param>
        /// <returns>Liste des citations non validées correspondant à la pagination.</returns>
        public Task<List<Quote>> getSomeQuoteInvalid(int nb, int page);

        /// <summary>
        /// Récupère le nombre total de citations enregistrées.
        /// </summary>
        /// <returns>Nombre total de citations.</returns>
        public Task<int> getNbQuote();

        /// <summary>
        /// Récupère la liste des personnages associés aux citations.
        /// </summary>
        /// <returns>Liste des personnages.</returns>
        public Task<List<Character>> getChar();

        /// <summary>
        /// Récupère la liste des sources associées aux citations.
        /// </summary>
        /// <returns>Liste des sources.</returns>
        public Task<List<Source>> getSrc();
    }
}
