﻿using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service
{
    /// <summary>
    /// Interface définissant les opérations de gestion des utilisateurs.
    /// </summary>
    public interface IUserService
    {
        /// <summary>
        /// Supprime un utilisateur du système.
        /// </summary>
        /// <param name="user">Utilisateur à supprimer.</param>
        public Task removeUser(User user);

        /// <summary>
        /// Met à jour le rôle d'un utilisateur.
        /// </summary>
        /// <param name="user">Utilisateur dont le rôle doit être mis à jour.</param>
        public Task updateRole(User user);

        /// <summary>
        /// Rétrograde le rôle d'un utilisateur.
        /// </summary>
        /// <param name="user">Utilisateur à rétrograder.</param>
        public Task downgradeRole(User user);

        /// <summary>
        /// Met à jour les informations d'un utilisateur.
        /// </summary>
        /// <param name="user">Utilisateur à mettre à jour.</param>
        public Task updateUser(User user);

        /// <summary>
        /// Récupère la liste complète des utilisateurs.
        /// </summary>
        /// <returns>Liste des utilisateurs.</returns>
        public Task<List<User>> getAllUser();

        /// <summary>
        /// Récupère une liste paginée d'utilisateurs.
        /// </summary>
        /// <param name="nb">Nombre d'utilisateurs par page.</param>
        /// <param name="page">Numéro de la page.</param>
        /// <returns>Liste des utilisateurs correspondant à la pagination.</returns>
        public Task<List<User>> getSomeUser(int nb, int page);

        /// <summary>
        /// Récupère un utilisateur spécifique par son identifiant.
        /// </summary>
        /// <param name="id">Identifiant de l'utilisateur.</param>
        /// <returns>L'utilisateur correspondant ou null s'il n'existe pas.</returns>
        public Task<User> getOneUser(int id);

        /// <summary>
        /// Recherche des utilisateurs en fonction d'un critère.
        /// </summary>
        /// <param name="reserch">Terme de recherche.</param>
        /// <param name="args">Liste des arguments pour affiner la recherche.</param>
        /// <returns>Liste des utilisateurs correspondant aux critères.</returns>
        public Task<List<User>> reserchUsers(string reserch, List<string> args);

        /// <summary>
        /// Récupère le nombre total d'utilisateurs enregistrés.
        /// </summary>
        /// <returns>Nombre total d'utilisateurs.</returns>
        public Task<int> getNbUser();
    }
}
