﻿using WF_WebAdmin.Converter;
using WF_WebAdmin.Model;
using Npgsql;

namespace WF_WebAdmin.Service
{
    /// <summary>
    /// Service de gestion des citations utilisant une base de données PostgreSQL.
    /// </summary>
    public class QuoteServiceLocal : IQuoteService
    {
        private readonly string? _connectionString = "Host=localhost;Port=5432;Username=loguichard3;Password=Reglisse15.;Database=dbloguichard3";

        /// <summary>
        /// Ajoute une nouvelle citation à la base de données PostgreSQL.
        /// </summary>
        /// <param name="quote">Citation à ajouter.</param>
        /// <returns>Un objet <see cref="QuoteDTO"/> représentant la citation ajoutée.</returns>
        public async Task<QuoteDTO> AddQuoteAsync(Quote quote)
        {
            QuoteExtension extension = new QuoteExtension();
            QuoteDTO quoteDTO = extension.QuoteToDTO(quote);

            using (var connection = new NpgsqlConnection(_connectionString))
            {
                var commandText = "INSERT INTO Quote (content, langue, reason, id_source, id_caracter, id_user_verif, img_path) " +
                                  "VALUES (@content, @langue, @reason, @source, @character, @user, @img_path)";

                var command = new NpgsqlCommand(commandText, connection);

                /*
                // Ajouter des paramètres à la commande
                command.Parameters.AddWithValue("@content", quote.Content);
                command.Parameters.AddWithValue("@langue", quote.Langue);
                command.Parameters.AddWithValue("@reason", "À vérifier"); // Vous pouvez changer ça si nécessaire
                command.Parameters.AddWithValue("@source", quote.Source);
                command.Parameters.AddWithValue("@character", quote.Character);
                command.Parameters.AddWithValue("@user", quote.User); // Assurez-vous que `quote.User` est correctement défini
                command.Parameters.AddWithValue("@img_path", quote.ImgPath);
                */

                try
                {
                    await connection.OpenAsync();
                    await command.ExecuteNonQueryAsync();
                }
                catch (Exception ex)
                {
                    Console.WriteLine($"Une erreur est survenue lors de l'ajout de la citation : {ex.Message}");
                }
                finally
                {
                    await connection.CloseAsync();
                }
            }

            return quoteDTO;
        }

        /// <summary>
        /// Supprime une citation de la base de données.
        /// </summary>
        /// <param name="quote">Citation à supprimer.</param>
        public Task RemoveQuote(Quote quote)
        {
            QuoteExtension extension = new QuoteExtension();
            QuoteDTO quoteDTO = extension.QuoteToDTO(quote);

            return Task.FromResult(quoteDTO);
        }

        /// <summary>
        /// Valide une citation.
        /// </summary>
        /// <param name="quote">Citation à valider.</param>
        public Task validQuote(Quote quote)
        {
            QuoteExtension extension = new QuoteExtension();
            QuoteDTO quoteDTO = extension.QuoteToDTO(quote);

            return Task.FromResult(quoteDTO);
        }

        /// <summary>
        /// Met à jour une citation existante.
        /// </summary>
        /// <param name="quote">Citation mise à jour.</param>
        public Task updateQuote(Quote quote)
        {
            QuoteExtension extension = new QuoteExtension();
            QuoteDTO quoteDTO = extension.QuoteToDTO(quote);

            return Task.FromResult(quoteDTO);
        }

        /// <summary>
        /// Ajoute une citation (non implémenté).
        /// </summary>
        public Task addQuote(Quote quote)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Supprime une citation (non implémenté).
        /// </summary>
        public Task removeQuote(Quote quote)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère toutes les citations (non implémenté).
        /// </summary>
        public Task<List<Quote>> getAllQuote()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère un ensemble de citations paginées (non implémenté).
        /// </summary>
        public Task<List<Quote>> getSomeQuote(int nb, int page)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Recherche des citations selon des critères spécifiques (non implémenté).
        /// </summary>
        public Task<List<Quote>> reserchQuote(string reserch, List<string> argument)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère toutes les citations invalides (non implémenté).
        /// </summary>
        public Task<List<Quote>> getAllQuoteInvalid()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère une liste paginée de citations invalides (non implémenté).
        /// </summary>
        public Task<List<Quote>> getSomeQuoteInvalid(int nb, int page)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère une citation spécifique en fonction de son ID (non implémenté).
        /// </summary>
        public Task<Quote> getOnequote(int id)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère le nombre total de citations enregistrées (non implémenté).
        /// </summary>
        public Task<int> getNbQuote()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère la liste des personnages (non implémenté).
        /// </summary>
        public Task<List<Character>> getChar()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Récupère la liste des sources (non implémenté).
        /// </summary>
        public Task<List<Source>> getSrc()
        {
            throw new NotImplementedException();
        }
    }
}
